@@ -33,7 +33,7 @@ Usage::
     list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
     ```
 """
-from mypy_boto3_workmail.client import WorkMailClient as Client, WorkMailClient
+from mypy_boto3_workmail.client import WorkMailClient
 from mypy_boto3_workmail.paginator import (
     ListAliasesPaginator,
     ListGroupMembersPaginator,
@@ -45,6 +45,8 @@ from mypy_boto3_workmail.paginator import (
     ListUsersPaginator,
 )
 
+Client = WorkMailClient
+
 
 __all__ = (
     "Client",
